@@ -1,12 +1,13 @@
 # Log styles
 from . import styles_cms as style
 from . import label as label_base
-from . label import lumitext
+from .label import lumitext
+
 __all__ = [style, lumitext]
 
 
 # Experiment wrappers:
-def cmstext(text, **kwargs):
+def cmstext(text="", **kwargs):
     return label_base._exptext("CMS", text=text, italic=(False, True), **kwargs)
 
 
