@@ -208,7 +208,10 @@ def histplot(
         _yerr = None
 
     def get_stack(_h):
-        return np.cumsum(_h, axis=0)
+        if _nh > 1:
+            return np.cumsum(_h, axis=0)
+        else:
+            return _h
 
     def get_density(h, density=True, binwnorm=None, bins=bins):
         assert (not density) ^ (
@@ -484,7 +487,7 @@ def overlap(ax, bbox, get_vertices=False):
 
     # TODO Possibly other objects
 
-    vertices = np.concatenate([l.vertices for l in lines])
+    vertices = np.concatenate([line.vertices for line in lines])
     tvertices = [ax.transData.transform(v) for v in vertices]
 
     overlap = bbox.count_contains(tvertices) + bbox.count_overlaps(bboxes)
